<?php

namespace itguild\forms;

use itguild\forms\builders\SelectBuilder;
use itguild\forms\builders\TextAreaBuilder;
use itguild\forms\debug\Debug;
use itguild\forms\inputs\BaseInput;
use itguild\forms\inputs\Select;
use itguild\forms\inputs\TextArea;
use itguild\forms\templates\Template;

class ActiveForm
{
    private BaseInput $fieldObject;


    /**
     * @param string $action
     * @return void
     */
    public function beginForm(string $action): void
    {
        echo "<form method='POST' action='$action'>";
    }

    /**
     * @return void
     */
    public function endForm(): void
    {
        echo "</form>";

    }

    public function field($class, string $name, array $params = [])
    {
        if ($class === Select::class){
            $this->fieldObject = SelectBuilder::build($name, $params);
        }
        elseif ($class === TextArea::class){
            $this->fieldObject = TextAreaBuilder::build($name, $params);
        }
        else {
            $this->fieldObject = new $class($name, $params);
        }

        return $this;
    }

    public function setLabel(string $title): self
    {
        $this->fieldObject->setLabel($title);

        return $this;
    }

    public function setOptions(array $options): self
    {
        $this->fieldObject->setOptions($options);

        return $this;
    }

    public function setTemplate($template): self
    {
        $this->fieldObject->setTemplate($template);

        return $this;
    }

    public function render()
    {
        $this->fieldObject->create();
        $this->fieldObject->render();
    }

}