<?php

namespace itguild\forms\inputs;

use itguild\forms\traits\CreateParams;
use itguild\forms\inputs\BaseInput;
use itguild\forms\templates\bootstrap5\Bootstrap5Template;
use itguild\forms\templates\Simple\SimpleTemplate;
use itguild\forms\templates\Template;
class TextArea extends BaseInput
{
    use CreateParams;

    private $name;
    private $value;
    private $paramsArray;
    private bool $hasLabel = false;
    private string $labelTitle = '';
    private Template $textareaTemplate;
    /**
     * @param string $name
     * @param string $value
     * @param array $paramsArray
     */
    public function __construct(string $name, string $value = '', array $paramsArray = [])
    {
        $this->name = $name;
        $this->value = $value;
        $this->paramsArray = $paramsArray;
        $this->textareaTemplate = new SimpleTemplate();
    }

    /**
     * @return $this
     */
    public function create(): self
    {
        $paramsString = $this->createParams($this->paramsArray);
        $label = "";
        $textarea = "<textarea name='$this->name' $paramsString>$this->value</textarea>";
        if($this->hasLabel == true) {
            $label = "<label>$this->labelTitle</label>";
        }

        $this->html = str_replace('{textarea}', $textarea, $this->textareaTemplate->getTextAreaTemplate());
        $this->html = str_replace('{label}', $label, $this->html);

        return $this;
    }


    /**
     * @param string $name
     * @param string $value
     * @param array $paramsArray
     * @return void
     */
    public static function build(string $name, string $value, array $paramsArray = []): void
    {
        $textarea = new self($name, $value, $paramsArray);
        $textarea->create()->render();
    }

    /**
     * @param string $title
     * @return $this
     */
    public function setLabel(string $title): self
    {
        $this->hasLabel = true;
        $this->labelTitle = $title;

        return $this;
    }

    /**
     * @param $template
     * @return $this
     */
    public function setTemplate($template): self
    {
        $this->textareaTemplate = new $template();

        return $this;
    }


}